@@ -96,6 +96,5 @@ class BeefPlugin(PluginBase):
 
 
 
-def createPlugin(ignore_info=False):
-    return BeefPlugin(ignore_info=ignore_info)
-
+def createPlugin(ignore_info=False, hostname_resolution=True):
+    return BeefPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
