@@ -391,5 +391,5 @@ class FortifyParser:
         return text
 
 
-def createPlugin(ignore_info=False):
-    return FortifyPlugin(ignore_info=ignore_info)
+def createPlugin(ignore_info=False, hostname_resolution=True):
+    return FortifyPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
