@@ -12,7 +12,6 @@ import dateutil
 from urllib.parse import urlparse
 from packaging import version
 from faraday_plugins.plugins.plugin import PluginMultiLineJsonFormat
-from faraday_plugins.plugins.plugins_utils import resolve_hostname
 
 __author__ = "Nicolas Rebagliati"
 __copyright__ = "Copyright (c) 2021, Infobyte LLC"
@@ -46,7 +45,7 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
             vuln_dict = json.loads(vuln_json)
             host = vuln_dict.get('host')
             url_data = urlparse(host)
-            ip = vuln_dict.get("ip", resolve_hostname(url_data.hostname))
+            ip = vuln_dict.get("ip", self.resolve_hostname(url_data.hostname))
             host_id = self.createAndAddHost(
                 name=ip,
                 hostnames=[url_data.hostname])
@@ -189,7 +188,5 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
                 return False
 
 
-def createPlugin(ignore_info=False):
-    return NucleiPlugin(ignore_info=ignore_info)
-
-
+def createPlugin(ignore_info=False, hostname_resolution=True):
+    return NucleiPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
